Update copyright notices and docs
Change-Id: Idee9b24f42e41f85a68f64ceab5f14d525442e2e
diff --git a/core/leaf.hpp b/core/leaf.hpp
index 3f8b0a5..4ee11d3 100644
--- a/core/leaf.hpp
+++ b/core/leaf.hpp
@@ -1,26 +1,26 @@
/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/**
- * Copyright (c) 2014, Regents of the University of California
+ * Copyright (c) 2014-2017, Regents of the University of California
*
* This file is part of NSL (NDN Signature Logger).
* See AUTHORS.md for complete list of NSL authors and contributors.
*
* NSL is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.
*
* NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
* PURPOSE. See the GNU General Public License for more details.
*
- * You should have received a copy of the GNU General Public License along with
- * NSL, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
- *
- * See AUTHORS.md for complete list of nsl authors and contributors.
+ * You should have received a copy of the GNU General Public License along with NDN
+ * DeLorean, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef NSL_CORE_LEAF_HPP
-#define NSL_CORE_LEAF_HPP
+#ifndef NDN_DELOREAN_CORE_LEAF_HPP
+#define NDN_DELOREAN_CORE_LEAF_HPP
#include "common.hpp"
#include "util/non-negative-integer.hpp"
@@ -105,7 +105,7 @@
void
decode(const Data& data);
-NSL_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
+NDN_DELOREAN_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
/// @brief Encode to a wire format or estimate wire format
template<ndn::encoding::Tag TAG>
size_t
@@ -122,7 +122,7 @@
public:
static const Name EMPTY_NAME;
-NSL_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
+NDN_DELOREAN_PUBLIC_WITH_TESTS_ELSE_PRIVATE:
static const size_t N_LOGGER_LEAF_SUFFIX;
static const ssize_t OFFSET_LEAF_SEQNO;
static const ssize_t OFFSET_LEAF_HASH;
@@ -140,4 +140,4 @@
} // namespace nsl
-#endif // NSL_CORE_LEAF_HPP
+#endif // NDN_DELOREAN_CORE_LEAF_HPP
@@ -1,26 +1,26 @@
*
- * This file is part of NSL (NDN Signature Logger).
- * See AUTHORS.md for complete list of NSL authors and contributors.
+ * This file is part of NDN DeLorean, An Authentication System for Data Archives in
+ * Named Data Networking. See AUTHORS.md for complete list of NDN DeLorean authors
+ * and contributors.
*
@@ -1,26 +1,26 @@
*
- * NSL is free software: you can redistribute it and/or modify it under the terms
- * of the GNU General Public License as published by the Free Software Foundation,
- * either version 3 of the License, or (at your option) any later version.
+ * NDN DeLorean is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
*
@@ -1,26 +1,26 @@
*
- * NSL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE. See the GNU General Public License for more details.
+ * NDN DeLorean is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
*